@@ -1,10 +1,10 @@
-"plotLA" <-
-function(model, together=FALSE, sex=NULL, axes=TRUE, same.limits=TRUE, between=list(x=axes,y=axes), ylim=NULL, bands=1,
-         main="", xlab="", ylab="", cex.main=1.2, cex.lab=1, cex.strip=0.8, cex.axis=0.8, las=1, tck=0, tick.number=5,
-         lty.grid=3, col.grid="grey", pch=16, cex.points=0.5, col.points="black", lty.lines=1, lwd.lines=4,
-         col.lines=c("red","blue"), lty.bands=2*!together, lwd.bands=1, col.bands="black", plot=TRUE, ...)
+plotLA <- function(model, together=FALSE, sex=NULL, axes=TRUE, same.limits=TRUE, between=list(x=axes,y=axes), ylim=NULL,
+                   bands=1, main="", xlab="", ylab="", cex.main=1.2, cex.lab=1, cex.axis=0.8, cex.strip=0.8,
+                   col.strip="gray95", las=1, tck=0, tick.number=5, lty.grid=3, col.grid="gray", pch=16, cex.points=0.5,
+                   col.points="black", lty.lines=1, lwd.lines=4, col.lines=c("red","blue"), lty.bands=2*!together,
+                   lwd.bands=1, col.bands="black", plot=TRUE, ...)
 {
-  ## 1 DEFINE FUNCTIONS
+  ## 1  Define functions
   panel.each <- function(x, y, subscripts, col.points, col.lines, col.bands, ...)  # obs, fit, and bands in sex panels
   {
     panel.grid(h=-1, v=-1, lty=lty.grid, col=col.grid)
@@ -16,17 +16,19 @@ function(model, together=FALSE, sex=NULL, axes=TRUE, same.limits=TRUE, between=l
     panel.grid(h=-1, v=-1, lty=lty.grid, col=col.grid)
     one <- z==levels(z)[1]
     two <- z==levels(z)[2]
-    panel.superpose.2(x[one], y[one], subscripts=subscripts[one], pch=pch[1], cex=cex.points[1], col.symbol=col.points[1],
-                      lty=c(lty.lines[1],lty.bands[1]), lwd=c(lwd.lines[1],lwd.bands[1]), col.line=col.lines[1], ...)
-    panel.superpose.2(x[two], y[two], subscripts=subscripts[two], pch=pch[2], cex=cex.points[2], col.symbol=col.points[2],
-                      lty=c(lty.lines[2],lty.bands[1]), lwd=c(lwd.lines[2],lwd.bands[1]), col.line=col.lines[2], ...)
+    panel.superpose.2(x[one], y[one], subscripts=subscripts[one], pch=pch[1], cex=cex.points[1],
+                      col.symbol=col.points[1], lty=c(lty.lines[1],lty.bands[1]), lwd=c(lwd.lines[1],lwd.bands[1]),
+                      col.line=col.lines[1], ...)
+    panel.superpose.2(x[two], y[two], subscripts=subscripts[two], pch=pch[2], cex=cex.points[2],
+                      col.symbol=col.points[2], lty=c(lty.lines[2],lty.bands[1]), lwd=c(lwd.lines[2],lwd.bands[1]),
+                      col.line=col.lines[2], ...)
   }
-  ## 2 PARSE ARGS
+  ## 2  Parse args
   if(class(model) != "scape")
     stop("The 'model' argument should be a scape object, not ", chartr("."," ",class(model)), ".")
   relation <- if(same.limits) "same" else "free"
 
-  ## 3 PREPARE DATA (extract, rearrange, filter)
+  ## 3  Prepare data (extract, rearrange, filter)
   x <- model$LA
   obs <- x[!is.na(x$Obs),]
   fit <- aggregate(list(Fit=x$Fit,CV=x$CV), list(Sex=x$Sex,Age=x$Age), mean)
@@ -44,14 +46,10 @@ function(model, together=FALSE, sex=NULL, axes=TRUE, same.limits=TRUE, between=l
     x <- x[x$ObsFit!="Upper"|x$ObsFit!="Lower",]
   nsexes <- length(unique(x$Sex))
 
-  ## 4 PREPARE PLOT (check device, vectorize args, create list args)
-  require(grid, quietly=TRUE, warn.conflicts=FALSE)
-  require(lattice, quietly=TRUE, warn.conflicts=FALSE)
-  if(trellis.par.get()$background$col == "#909090")
-  {
-    for(d in dev.list()) dev.off()
-    trellis.device(color=FALSE)
-  }
+  ## 4  Prepare plot (set pars, vectorize args, create list args)
+  ocol <- trellis.par.get("strip.background")$col
+  trellis.par.set(strip.background=list(col=col.strip))
+  on.exit(trellis.par.set(strip.background=list(col=ocol)))
   pch <- rep(pch, length.out=2)
   cex.points <- rep(cex.points, length.out=2)
   col.points <- rep(col.points, length.out=2)
@@ -67,7 +65,7 @@ function(model, together=FALSE, sex=NULL, axes=TRUE, same.limits=TRUE, between=l
   myscales <- c(list(draw=axes,relation=relation,cex=cex.axis,tck=tck,tick.number=tick.number), myrot)
   mystrip <- list(cex=cex.strip)
 
-  ## 5 CREATE TRELLIS OBJECT
+  ## 5  Create trellis object
   if(is.null(ylim))
     ylim <- c(0, 1.04*max(x$Length))
   if(nsexes==2 && together)
@@ -80,12 +78,12 @@ function(model, together=FALSE, sex=NULL, axes=TRUE, same.limits=TRUE, between=l
   {
     graph <- xyplot(Length~Age|Sex, data=x, groups=x$ObsFit, panel=panel.each, type=c("l","l","p"), as.table=TRUE,
                     between=between, ylim=ylim, main=mymain, xlab=myxlab, ylab=myylab, scales=myscales,
-                    par.strip.text=mystrip, pch=pch, cex=cex.points, col.points=col.points[x$Sex],
-                    lty=c(lty.lines[1],lty.bands[1]), lwd=c(lwd.lines[1],lwd.bands[1]), col.lines=col.lines[x$Sex],
-                    col.bands=col.bands[x$Sex], ...)
+                    par.strip.text=mystrip, pch=pch, cex=cex.points, col.points=col.points[as.factor(x$Sex)],
+                    lty=c(lty.lines[1],lty.bands[1]), lwd=c(lwd.lines[1],lwd.bands[1]),
+                    col.lines=col.lines[as.factor(x$Sex)], col.bands=col.bands[as.factor(x$Sex)], ...)
   }
 
-  ## 6 FINISH
+  ## 6  Finish
   if(plot)
   {
     print(graph)
@@ -96,4 +94,3 @@ function(model, together=FALSE, sex=NULL, axes=TRUE, same.limits=TRUE, between=l
     invisible(graph)
   }
 }
-
